@@ -26,9 +26,10 @@
 #include <xorg-config.h>
 #endif
 
+#include <string.h>
+
 #include "misc.h"
 #include "xf86.h"
-#include "xf86_ansic.h"
 #include "xf86_OSproc.h"
 
 #include <X11/X.h>
